Stan Math Library: stan/math/rev/core/recover_memory.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
recover_memory.hpp File Reference
`#include <stan/math/rev/core/vari.hpp>`
`#include <stan/math/rev/core/chainablestack.hpp>`
`#include <stan/math/rev/core/empty_nested.hpp>`
`#include <stdexcept>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
static void | stan::math::recover_memory ()
| Recover memory used for all variables for reuse. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.